==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/WebFloatingPaneResizeEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebSplitPaneDescriptionMetadata } from "./WebSplitPaneDescriptionMetadata";
import { WebFloatingPaneResizeEventArgsDescription } from "./WebFloatingPaneResizeEventArgsDescription";
/**
 * @hidden
 */
var WebFloatingPaneResizeEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebFloatingPaneResizeEventArgsDescriptionMetadata, _super);
    function WebFloatingPaneResizeEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebFloatingPaneResizeEventArgsDescriptionMetadata.b = function (a) {
        if (WebFloatingPaneResizeEventArgsDescriptionMetadata.a == null) {
            WebFloatingPaneResizeEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebFloatingPaneResizeEventArgsDescriptionMetadata.c(WebFloatingPaneResizeEventArgsDescriptionMetadata.a);
        }
        if (a.j(WebFloatingPaneResizeEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.y(WebFloatingPaneResizeEventArgsDescriptionMetadata.a);
        WebSplitPaneDescriptionMetadata.d(a);
    };
    WebFloatingPaneResizeEventArgsDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:FloatingPaneResizeEventArgs");
        a.item("SourcePane", "ExportedType:WebSplitPane");
        a.item("ResizerLocation", "ExportedType:string:FloatingPaneResizeEventArgsResizerLocation");
        a.item("ResizerLocation@names", "Top;Bottom;Left;Right;TopLeft;TopRight;BottomLeft;BottomRight");
    };
    WebFloatingPaneResizeEventArgsDescriptionMetadata.d = function (a) {
        WebFloatingPaneResizeEventArgsDescriptionMetadata.b(a);
        a.aa("WebFloatingPaneResizeEventArgs", function () { return new WebFloatingPaneResizeEventArgsDescription(); });
        a.z("WebFloatingPaneResizeEventArgs", WebFloatingPaneResizeEventArgsDescriptionMetadata.a);
    };
    WebFloatingPaneResizeEventArgsDescriptionMetadata.$t = markType(WebFloatingPaneResizeEventArgsDescriptionMetadata, 'WebFloatingPaneResizeEventArgsDescriptionMetadata');
    WebFloatingPaneResizeEventArgsDescriptionMetadata.a = null;
    return WebFloatingPaneResizeEventArgsDescriptionMetadata;
}(Base));
export { WebFloatingPaneResizeEventArgsDescriptionMetadata };

==> igniteui-react-core-18.1.3.tgz: package/esm5/lib/WebFloatingPaneResizeEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebFloatingPaneResizeEventArgsDetailDescriptionMetadata } from "./WebFloatingPaneResizeEventArgsDetailDescriptionMetadata";
import { WebFloatingPaneResizeEventArgsDescription } from "./WebFloatingPaneResizeEventArgsDescription";
/**
 * @hidden
 */
var WebFloatingPaneResizeEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebFloatingPaneResizeEventArgsDescriptionMetadata, _super);
    function WebFloatingPaneResizeEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebFloatingPaneResizeEventArgsDescriptionMetadata.b = function (a) {
        if (WebFloatingPaneResizeEventArgsDescriptionMetadata.a == null) {
            WebFloatingPaneResizeEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebFloatingPaneResizeEventArgsDescriptionMetadata.c(WebFloatingPaneResizeEventArgsDescriptionMetadata.a);
        }
        if (a.k(WebFloatingPaneResizeEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.aa(WebFloatingPaneResizeEventArgsDescriptionMetadata.a);
        WebFloatingPaneResizeEventArgsDetailDescriptionMetadata.d(a);
    };
    WebFloatingPaneResizeEventArgsDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:FloatingPaneResizeEventArgs");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
        a.item("__skipSuffix", "Boolean");
        a.item("Detail", "ExportedType:WebFloatingPaneResizeEventArgsDetail");
    };
    WebFloatingPaneResizeEventArgsDescriptionMetadata.d = function (a) {
        WebFloatingPaneResizeEventArgsDescriptionMetadata.b(a);
        a.ac("WebFloatingPaneResizeEventArgs", function () { return new WebFloatingPaneResizeEventArgsDescription(); });
        a.ab("WebFloatingPaneResizeEventArgs", WebFloatingPaneResizeEventArgsDescriptionMetadata.a);
    };
    WebFloatingPaneResizeEventArgsDescriptionMetadata.$t = markType(WebFloatingPaneResizeEventArgsDescriptionMetadata, 'WebFloatingPaneResizeEventArgsDescriptionMetadata');
    WebFloatingPaneResizeEventArgsDescriptionMetadata.a = null;
    return WebFloatingPaneResizeEventArgsDescriptionMetadata;
}(Base));
export { WebFloatingPaneResizeEventArgsDescriptionMetadata };
